@@ -14,10 +14,17 @@
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
-VERSION = (1, 4, 9)
-__version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
+from collections import namedtuple
+
+version_info_t = namedtuple(
+    'version_info_t', ('major', 'minor', 'micro', 'releaselevel', 'serial'),
+)
+
+VERSION = version_info = version_info_t(2, 0, 0, '', '')
+
+__version__ = '{0.major}.{0.minor}.{0.micro}{0.releaselevel}'.format(VERSION)
 __author__ = 'Barry Pederson'
 __maintainer__ = 'Ask Solem'
 __contact__ = 'pyamqp@celeryproject.org'
@@ -61,10 +68,10 @@ from .exceptions import (               # noqa
     error_for_code,
     __all__ as _all_exceptions,
 )
-from .utils import promise  # noqa
 
 __all__ = [
     'Connection',
     'Channel',
     'Message',
-] + _all_exceptions
+]
+__all__ += _all_exceptions
